'''OpenGL extension NV.vertex_program

This module customises the behaviour of the 
OpenGL.raw.GL.NV.vertex_program to provide a more 
Python-friendly API

Overview (from the spec)
	
	Unextended OpenGL mandates a certain set of configurable per-vertex
	computations defining vertex transformation, texture coordinate
	generation and transformation, and lighting.  Several extensions
	have added further per-vertex computations to OpenGL.  For example,
	extensions have defined new texture coordinate generation modes
	(ARB_texture_cube_map, NV_texgen_reflection, NV_texgen_emboss), new
	vertex transformation modes (EXT_vertex_weighting), new lighting modes
	(OpenGL 1.2's separate specular and rescale normal functionality),
	several modes for fog distance generation (NV_fog_distance), and
	eye-distance point size attenuation (EXT_point_parameters).
	
	Each such extension adds a small set of relatively inflexible
	per-vertex computations.
	
	This inflexibility is in contrast to the typical flexibility provided
	by the underlying programmable floating point engines (whether
	micro-coded vertex engines, DSPs, or CPUs) that are traditionally used
	to implement OpenGL's per-vertex computations.  The purpose of this
	extension is to expose to the OpenGL application writer a significant
	degree of per-vertex programmability for computing vertex parameters.
	
	For the purposes of discussing this extension, a vertex program is
	a sequence of floating-point 4-component vector operations that
	determines how a set of program parameters (defined outside of
	OpenGL's begin/end pair) and an input set of per-vertex parameters
	are transformed to a set of per-vertex output parameters.
	
	The per-vertex computations for standard OpenGL given a particular
	set of lighting and texture coordinate generation modes (along with
	any state for extensions defining per-vertex computations) is, in
	essence, a vertex program.  However, the sequence of operations is
	defined implicitly by the current OpenGL state settings rather than
	defined explicitly as a sequence of instructions.
	
	This extension provides an explicit mechanism for defining vertex
	program instruction sequences for application-defined vertex programs.
	In order to define such vertex programs, this extension defines
	a vertex programming model including a floating-point 4-component
	vector instruction set and a relatively large set of floating-point
	4-component registers.
	
	The extension's vertex programming model is designed for efficient
	hardware implementation and to support a wide variety of vertex
	programs.  By design, the entire set of existing vertex programs
	defined by existing OpenGL per-vertex computation extensions can be
	implemented using the extension's vertex programming model.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/vertex_program.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.NV.vertex_program import *
### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.list_priority

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.list_priority to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism for specifying the relative
	importance of display lists.  This information can be used by
	an OpenGL implementation to guide the placement of display
	list data in a storage hierarchy.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/list_priority.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.SGIX.list_priority import *
### END AUTOGENERATED SECTION


'''OpenGL extension PGI.vertex_hints

This module customises the behaviour of the 
OpenGL.raw.GL.PGI.vertex_hints to provide a more 
Python-friendly API

Overview (from the spec)
	
	The extension allows the app to give hints regarding what kinds of
	OpenGL function calls will happen between Begin/End pairs.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/PGI/vertex_hints.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.PGI.vertex_hints import *
### END AUTOGENERATED SECTION


'''OpenGL extension ATI.envmap_bumpmap

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_envmap_bumpmap'
_DEPRECATED = False
GL_BUMP_ROT_MATRIX_ATI = constant.Constant( 'GL_BUMP_ROT_MATRIX_ATI', 0x8775 )
GL_BUMP_ROT_MATRIX_SIZE_ATI = constant.Constant( 'GL_BUMP_ROT_MATRIX_SIZE_ATI', 0x8776 )
GL_BUMP_NUM_TEX_UNITS_ATI = constant.Constant( 'GL_BUMP_NUM_TEX_UNITS_ATI', 0x8777 )
GL_BUMP_TEX_UNITS_ATI = constant.Constant( 'GL_BUMP_TEX_UNITS_ATI', 0x8778 )
GL_DUDV_ATI = constant.Constant( 'GL_DUDV_ATI', 0x8779 )
GL_DU8DV8_ATI = constant.Constant( 'GL_DU8DV8_ATI', 0x877A )
GL_BUMP_ENVMAP_ATI = constant.Constant( 'GL_BUMP_ENVMAP_ATI', 0x877B )
GL_BUMP_TARGET_ATI = constant.Constant( 'GL_BUMP_TARGET_ATI', 0x877C )
glTexBumpParameterivATI = platform.createExtensionFunction( 
'glTexBumpParameterivATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glTexBumpParameterivATI(GLenum(pname), GLintArray(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)

glTexBumpParameterfvATI = platform.createExtensionFunction( 
'glTexBumpParameterfvATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glTexBumpParameterfvATI(GLenum(pname), GLfloatArray(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)

glGetTexBumpParameterivATI = platform.createExtensionFunction( 
'glGetTexBumpParameterivATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glGetTexBumpParameterivATI(GLenum(pname), GLintArray(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)

glGetTexBumpParameterfvATI = platform.createExtensionFunction( 
'glGetTexBumpParameterfvATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glGetTexBumpParameterfvATI(GLenum(pname), GLfloatArray(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)


def glInitEnvmapBumpmapATI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIS.point_line_texgen

This module customises the behaviour of the 
OpenGL.raw.GL.SGIS.point_line_texgen to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds two texture coordinate generation modes, both
	which generate a texture coordinate based on the minimum distance 
	from a vertex to a specified line.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/point_line_texgen.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.SGIS.point_line_texgen import *
### END AUTOGENERATED SECTION


'''OpenGL extension PGI.misc_hints

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_PGI_misc_hints'
_DEPRECATED = False
GL_PREFER_DOUBLEBUFFER_HINT_PGI = constant.Constant( 'GL_PREFER_DOUBLEBUFFER_HINT_PGI', 0x1A1F8 )
GL_CONSERVE_MEMORY_HINT_PGI = constant.Constant( 'GL_CONSERVE_MEMORY_HINT_PGI', 0x1A1FD )
GL_RECLAIM_MEMORY_HINT_PGI = constant.Constant( 'GL_RECLAIM_MEMORY_HINT_PGI', 0x1A1FE )
GL_NATIVE_GRAPHICS_HANDLE_PGI = constant.Constant( 'GL_NATIVE_GRAPHICS_HANDLE_PGI', 0x1A202 )
GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI = constant.Constant( 'GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI', 0x1A203 )
GL_NATIVE_GRAPHICS_END_HINT_PGI = constant.Constant( 'GL_NATIVE_GRAPHICS_END_HINT_PGI', 0x1A204 )
GL_ALWAYS_FAST_HINT_PGI = constant.Constant( 'GL_ALWAYS_FAST_HINT_PGI', 0x1A20C )
GL_ALWAYS_SOFT_HINT_PGI = constant.Constant( 'GL_ALWAYS_SOFT_HINT_PGI', 0x1A20D )
GL_ALLOW_DRAW_OBJ_HINT_PGI = constant.Constant( 'GL_ALLOW_DRAW_OBJ_HINT_PGI', 0x1A20E )
GL_ALLOW_DRAW_WIN_HINT_PGI = constant.Constant( 'GL_ALLOW_DRAW_WIN_HINT_PGI', 0x1A20F )
GL_ALLOW_DRAW_FRG_HINT_PGI = constant.Constant( 'GL_ALLOW_DRAW_FRG_HINT_PGI', 0x1A210 )
GL_ALLOW_DRAW_MEM_HINT_PGI = constant.Constant( 'GL_ALLOW_DRAW_MEM_HINT_PGI', 0x1A211 )
GL_STRICT_DEPTHFUNC_HINT_PGI = constant.Constant( 'GL_STRICT_DEPTHFUNC_HINT_PGI', 0x1A216 )
GL_STRICT_LIGHTING_HINT_PGI = constant.Constant( 'GL_STRICT_LIGHTING_HINT_PGI', 0x1A217 )
GL_STRICT_SCISSOR_HINT_PGI = constant.Constant( 'GL_STRICT_SCISSOR_HINT_PGI', 0x1A218 )
GL_FULL_STIPPLE_HINT_PGI = constant.Constant( 'GL_FULL_STIPPLE_HINT_PGI', 0x1A219 )
GL_CLIP_NEAR_HINT_PGI = constant.Constant( 'GL_CLIP_NEAR_HINT_PGI', 0x1A220 )
GL_CLIP_FAR_HINT_PGI = constant.Constant( 'GL_CLIP_FAR_HINT_PGI', 0x1A221 )
GL_WIDE_LINE_HINT_PGI = constant.Constant( 'GL_WIDE_LINE_HINT_PGI', 0x1A222 )
GL_BACK_NORMALS_HINT_PGI = constant.Constant( 'GL_BACK_NORMALS_HINT_PGI', 0x1A223 )
glHintPGI = platform.createExtensionFunction( 
'glHintPGI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,),
doc='glHintPGI(GLenum(target), GLint(mode)) -> None',
argNames=('target','mode',),
deprecated=_DEPRECATED,
)


def glInitMiscHintsPGI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



"""Provides the common meta-data for the various setup scripts"""
import os
metadata = dict(
    version = [
        (line.split('=')[1]).strip().strip('"').strip("'")
        for line in open(os.path.join('OpenGL','version.py'))
        if line.startswith( '__version__' )
    ][0],
    author = 'Mike C. Fletcher',
    author_email = 'mcfletch@vrplumber.com',
    url = 'http://pyopengl.sourceforge.net',
    license = 'BSD',
    download_url = "http://sourceforge.net/projects/pyopengl/files/PyOpenGL/",
    keywords = 'Graphics,3D,OpenGL,GLU,GLUT,GLE,GLX,EXT,ARB,Mesa,ctypes',
    classifiers = [
        """License :: OSI Approved :: BSD License""",
        """Programming Language :: Python""",
        """Topic :: Multimedia :: Graphics :: 3D Rendering""",
        """Topic :: Software Development :: Libraries :: Python Modules""",
        """Intended Audience :: Developers""",
    ],
)


'''OpenGL extension ATI.texture_mirror_once

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_texture_mirror_once'
_DEPRECATED = False
GL_MIRROR_CLAMP_ATI = constant.Constant( 'GL_MIRROR_CLAMP_ATI', 0x8742 )
GL_MIRROR_CLAMP_TO_EDGE_ATI = constant.Constant( 'GL_MIRROR_CLAMP_TO_EDGE_ATI', 0x8743 )


def glInitTextureMirrorOnceATI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



#! /usr/bin/env python
import unittest

class TestFCO( unittest.TestCase ):
    def test_fco_import( self ):
        import OpenGL
        OpenGL.FORWARD_COMPATIBLE_ONLY = True
        from OpenGL import GL, GLU, GLUT

if __name__ == "__main__":
    unittest.main()



'''OpenGL extension EXT.direct_state_access

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_direct_state_access'
_DEPRECATED = False
GL_PROGRAM_MATRIX_EXT = constant.Constant( 'GL_PROGRAM_MATRIX_EXT', 0x8E2D )
GL_TRANSPOSE_PROGRAM_MATRIX_EXT = constant.Constant( 'GL_TRANSPOSE_PROGRAM_MATRIX_EXT', 0x8E2E )
GL_PROGRAM_MATRIX_STACK_DEPTH_EXT = constant.Constant( 'GL_PROGRAM_MATRIX_STACK_DEPTH_EXT', 0x8E2F )
glClientAttribDefaultEXT = platform.createExtensionFunction( 
'glClientAttribDefaultEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLbitfield,),
doc='glClientAttribDefaultEXT(GLbitfield(mask)) -> None',
argNames=('mask',),
deprecated=_DEPRECATED,
)

glPushClientAttribDefaultEXT = platform.createExtensionFunction( 
'glPushClientAttribDefaultEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLbitfield,),
doc='glPushClientAttribDefaultEXT(GLbitfield(mask)) -> None',
argNames=('mask',),
deprecated=_DEPRECATED,
)

glMatrixLoadfEXT = platform.createExtensionFunction( 
'glMatrixLoadfEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMatrixLoadfEXT(GLenum(mode), GLfloatArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixLoaddEXT = platform.createExtensionFunction( 
'glMatrixLoaddEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMatrixLoaddEXT(GLenum(mode), GLdoubleArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixMultfEXT = platform.createExtensionFunction( 
'glMatrixMultfEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMatrixMultfEXT(GLenum(mode), GLfloatArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixMultdEXT = platform.createExtensionFunction( 
'glMatrixMultdEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMatrixMultdEXT(GLenum(mode), GLdoubleArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixLoadIdentityEXT = platform.createExtensionFunction( 
'glMatrixLoadIdentityEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glMatrixLoadIdentityEXT(GLenum(mode)) -> None',
argNames=('mode',),
deprecated=_DEPRECATED,
)

glMatrixRotatefEXT = platform.createExtensionFunction( 
'glMatrixRotatefEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glMatrixRotatefEXT(GLenum(mode), GLfloat(angle), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('mode','angle','x','y','z',),
deprecated=_DEPRECATED,
)

glMatrixRotatedEXT = platform.createExtensionFunction( 
'glMatrixRotatedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMatrixRotatedEXT(GLenum(mode), GLdouble(angle), GLdouble(x), GLdouble(y), GLdouble(z)) -> None',
argNames=('mode','angle','x','y','z',),
deprecated=_DEPRECATED,
)

glMatrixScalefEXT = platform.createExtensionFunction( 
'glMatrixScalefEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glMatrixScalefEXT(GLenum(mode), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('mode','x','y','z',),
deprecated=_DEPRECATED,
)

glMatrixScaledEXT = platform.createExtensionFunction( 
'glMatrixScaledEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMatrixScaledEXT(GLenum(mode), GLdouble(x), GLdouble(y), GLdouble(z)) -> None',
argNames=('mode','x','y','z',),
deprecated=_DEPRECATED,
)

glMatrixTranslatefEXT = platform.createExtensionFunction( 
'glMatrixTranslatefEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glMatrixTranslatefEXT(GLenum(mode), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('mode','x','y','z',),
deprecated=_DEPRECATED,
)

glMatrixTranslatedEXT = platform.createExtensionFunction( 
'glMatrixTranslatedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMatrixTranslatedEXT(GLenum(mode), GLdouble(x), GLdouble(y), GLdouble(z)) -> None',
argNames=('mode','x','y','z',),
deprecated=_DEPRECATED,
)

glMatrixFrustumEXT = platform.createExtensionFunction( 
'glMatrixFrustumEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMatrixFrustumEXT(GLenum(mode), GLdouble(left), GLdouble(right), GLdouble(bottom), GLdouble(top), GLdouble(zNear), GLdouble(zFar)) -> None',
argNames=('mode','left','right','bottom','top','zNear','zFar',),
deprecated=_DEPRECATED,
)

glMatrixOrthoEXT = platform.createExtensionFunction( 
'glMatrixOrthoEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMatrixOrthoEXT(GLenum(mode), GLdouble(left), GLdouble(right), GLdouble(bottom), GLdouble(top), GLdouble(zNear), GLdouble(zFar)) -> None',
argNames=('mode','left','right','bottom','top','zNear','zFar',),
deprecated=_DEPRECATED,
)

glMatrixPopEXT = platform.createExtensionFunction( 
'glMatrixPopEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glMatrixPopEXT(GLenum(mode)) -> None',
argNames=('mode',),
deprecated=_DEPRECATED,
)

glMatrixPushEXT = platform.createExtensionFunction( 
'glMatrixPushEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glMatrixPushEXT(GLenum(mode)) -> None',
argNames=('mode',),
deprecated=_DEPRECATED,
)

glMatrixLoadTransposefEXT = platform.createExtensionFunction( 
'glMatrixLoadTransposefEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMatrixLoadTransposefEXT(GLenum(mode), GLfloatArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixLoadTransposedEXT = platform.createExtensionFunction( 
'glMatrixLoadTransposedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMatrixLoadTransposedEXT(GLenum(mode), GLdoubleArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixMultTransposefEXT = platform.createExtensionFunction( 
'glMatrixMultTransposefEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMatrixMultTransposefEXT(GLenum(mode), GLfloatArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glMatrixMultTransposedEXT = platform.createExtensionFunction( 
'glMatrixMultTransposedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMatrixMultTransposedEXT(GLenum(mode), GLdoubleArray(m)) -> None',
argNames=('mode','m',),
deprecated=_DEPRECATED,
)

glTextureParameterfEXT = platform.createExtensionFunction( 
'glTextureParameterfEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLfloat,),
doc='glTextureParameterfEXT(GLuint(texture), GLenum(target), GLenum(pname), GLfloat(param)) -> None',
argNames=('texture','target','pname','param',),
deprecated=_DEPRECATED,
)

glTextureParameterfvEXT = platform.createExtensionFunction( 
'glTextureParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glTextureParameterfvEXT(GLuint(texture), GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glTextureParameteriEXT = platform.createExtensionFunction( 
'glTextureParameteriEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLint,),
doc='glTextureParameteriEXT(GLuint(texture), GLenum(target), GLenum(pname), GLint(param)) -> None',
argNames=('texture','target','pname','param',),
deprecated=_DEPRECATED,
)

glTextureParameterivEXT = platform.createExtensionFunction( 
'glTextureParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glTextureParameterivEXT(GLuint(texture), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glTextureImage1DEXT = platform.createExtensionFunction( 
'glTextureImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTextureImage1DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','internalformat','width','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glTextureImage2DEXT = platform.createExtensionFunction( 
'glTextureImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTextureImage2DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','internalformat','width','height','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glTextureSubImage1DEXT = platform.createExtensionFunction( 
'glTextureSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTextureSubImage1DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','xoffset','width','format','type','pixels',),
deprecated=_DEPRECATED,
)

glTextureSubImage2DEXT = platform.createExtensionFunction( 
'glTextureSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTextureSubImage2DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','xoffset','yoffset','width','height','format','type','pixels',),
deprecated=_DEPRECATED,
)

glCopyTextureImage1DEXT = platform.createExtensionFunction( 
'glCopyTextureImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLint,),
doc='glCopyTextureImage1DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLint(border)) -> None',
argNames=('texture','target','level','internalformat','x','y','width','border',),
deprecated=_DEPRECATED,
)

glCopyTextureImage2DEXT = platform.createExtensionFunction( 
'glCopyTextureImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLint,),
doc='glCopyTextureImage2DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLsizei(height), GLint(border)) -> None',
argNames=('texture','target','level','internalformat','x','y','width','height','border',),
deprecated=_DEPRECATED,
)

glCopyTextureSubImage1DEXT = platform.createExtensionFunction( 
'glCopyTextureSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,),
doc='glCopyTextureSubImage1DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(x), GLint(y), GLsizei(width)) -> None',
argNames=('texture','target','level','xoffset','x','y','width',),
deprecated=_DEPRECATED,
)

glCopyTextureSubImage2DEXT = platform.createExtensionFunction( 
'glCopyTextureSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glCopyTextureSubImage2DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height)) -> None',
argNames=('texture','target','level','xoffset','yoffset','x','y','width','height',),
deprecated=_DEPRECATED,
)

glGetTextureImageEXT = platform.createExtensionFunction( 
'glGetTextureImageEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glGetTextureImageEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','format','type','pixels',),
deprecated=_DEPRECATED,
)

glGetTextureParameterfvEXT = platform.createExtensionFunction( 
'glGetTextureParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetTextureParameterfvEXT(GLuint(texture), GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetTextureParameterivEXT = platform.createExtensionFunction( 
'glGetTextureParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetTextureParameterivEXT(GLuint(texture), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetTextureLevelParameterfvEXT = platform.createExtensionFunction( 
'glGetTextureLevelParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetTextureLevelParameterfvEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texture','target','level','pname','params',),
deprecated=_DEPRECATED,
)

glGetTextureLevelParameterivEXT = platform.createExtensionFunction( 
'glGetTextureLevelParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,arrays.GLintArray,),
doc='glGetTextureLevelParameterivEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(pname), GLintArray(params)) -> None',
argNames=('texture','target','level','pname','params',),
deprecated=_DEPRECATED,
)

glTextureImage3DEXT = platform.createExtensionFunction( 
'glTextureImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTextureImage3DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','internalformat','width','height','depth','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glTextureSubImage3DEXT = platform.createExtensionFunction( 
'glTextureSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTextureSubImage3DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texture','target','level','xoffset','yoffset','zoffset','width','height','depth','format','type','pixels',),
deprecated=_DEPRECATED,
)

glCopyTextureSubImage3DEXT = platform.createExtensionFunction( 
'glCopyTextureSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glCopyTextureSubImage3DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height)) -> None',
argNames=('texture','target','level','xoffset','yoffset','zoffset','x','y','width','height',),
deprecated=_DEPRECATED,
)

glMultiTexParameterfEXT = platform.createExtensionFunction( 
'glMultiTexParameterfEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLfloat,),
doc='glMultiTexParameterfEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLfloat(param)) -> None',
argNames=('texunit','target','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexParameterfvEXT = platform.createExtensionFunction( 
'glMultiTexParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexParameterfvEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexParameteriEXT = platform.createExtensionFunction( 
'glMultiTexParameteriEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLint,),
doc='glMultiTexParameteriEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLint(param)) -> None',
argNames=('texunit','target','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexParameterivEXT = platform.createExtensionFunction( 
'glMultiTexParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glMultiTexParameterivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexImage1DEXT = platform.createExtensionFunction( 
'glMultiTexImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glMultiTexImage1DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','internalformat','width','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glMultiTexImage2DEXT = platform.createExtensionFunction( 
'glMultiTexImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glMultiTexImage2DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','internalformat','width','height','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glMultiTexSubImage1DEXT = platform.createExtensionFunction( 
'glMultiTexSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glMultiTexSubImage1DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','xoffset','width','format','type','pixels',),
deprecated=_DEPRECATED,
)

glMultiTexSubImage2DEXT = platform.createExtensionFunction( 
'glMultiTexSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glMultiTexSubImage2DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','xoffset','yoffset','width','height','format','type','pixels',),
deprecated=_DEPRECATED,
)

glCopyMultiTexImage1DEXT = platform.createExtensionFunction( 
'glCopyMultiTexImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLint,),
doc='glCopyMultiTexImage1DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLint(border)) -> None',
argNames=('texunit','target','level','internalformat','x','y','width','border',),
deprecated=_DEPRECATED,
)

glCopyMultiTexImage2DEXT = platform.createExtensionFunction( 
'glCopyMultiTexImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLint,),
doc='glCopyMultiTexImage2DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLsizei(height), GLint(border)) -> None',
argNames=('texunit','target','level','internalformat','x','y','width','height','border',),
deprecated=_DEPRECATED,
)

glCopyMultiTexSubImage1DEXT = platform.createExtensionFunction( 
'glCopyMultiTexSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,),
doc='glCopyMultiTexSubImage1DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(x), GLint(y), GLsizei(width)) -> None',
argNames=('texunit','target','level','xoffset','x','y','width',),
deprecated=_DEPRECATED,
)

glCopyMultiTexSubImage2DEXT = platform.createExtensionFunction( 
'glCopyMultiTexSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glCopyMultiTexSubImage2DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height)) -> None',
argNames=('texunit','target','level','xoffset','yoffset','x','y','width','height',),
deprecated=_DEPRECATED,
)

glGetMultiTexImageEXT = platform.createExtensionFunction( 
'glGetMultiTexImageEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glGetMultiTexImageEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','format','type','pixels',),
deprecated=_DEPRECATED,
)

glGetMultiTexParameterfvEXT = platform.createExtensionFunction( 
'glGetMultiTexParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetMultiTexParameterfvEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexParameterivEXT = platform.createExtensionFunction( 
'glGetMultiTexParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetMultiTexParameterivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexLevelParameterfvEXT = platform.createExtensionFunction( 
'glGetMultiTexLevelParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetMultiTexLevelParameterfvEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','target','level','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexLevelParameterivEXT = platform.createExtensionFunction( 
'glGetMultiTexLevelParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,arrays.GLintArray,),
doc='glGetMultiTexLevelParameterivEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','level','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexImage3DEXT = platform.createExtensionFunction( 
'glMultiTexImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glMultiTexImage3DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','internalformat','width','height','depth','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glMultiTexSubImage3DEXT = platform.createExtensionFunction( 
'glMultiTexSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glMultiTexSubImage3DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('texunit','target','level','xoffset','yoffset','zoffset','width','height','depth','format','type','pixels',),
deprecated=_DEPRECATED,
)

glCopyMultiTexSubImage3DEXT = platform.createExtensionFunction( 
'glCopyMultiTexSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glCopyMultiTexSubImage3DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height)) -> None',
argNames=('texunit','target','level','xoffset','yoffset','zoffset','x','y','width','height',),
deprecated=_DEPRECATED,
)

glBindMultiTextureEXT = platform.createExtensionFunction( 
'glBindMultiTextureEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glBindMultiTextureEXT(GLenum(texunit), GLenum(target), GLuint(texture)) -> None',
argNames=('texunit','target','texture',),
deprecated=_DEPRECATED,
)

glEnableClientStateIndexedEXT = platform.createExtensionFunction( 
'glEnableClientStateIndexedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glEnableClientStateIndexedEXT(GLenum(array), GLuint(index)) -> None',
argNames=('array','index',),
deprecated=_DEPRECATED,
)

glDisableClientStateIndexedEXT = platform.createExtensionFunction( 
'glDisableClientStateIndexedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glDisableClientStateIndexedEXT(GLenum(array), GLuint(index)) -> None',
argNames=('array','index',),
deprecated=_DEPRECATED,
)

glMultiTexCoordPointerEXT = platform.createExtensionFunction( 
'glMultiTexCoordPointerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glMultiTexCoordPointerEXT(GLenum(texunit), GLint(size), GLenum(type), GLsizei(stride), c_void_p(pointer)) -> None',
argNames=('texunit','size','type','stride','pointer',),
deprecated=_DEPRECATED,
)

glMultiTexEnvfEXT = platform.createExtensionFunction( 
'glMultiTexEnvfEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLfloat,),
doc='glMultiTexEnvfEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLfloat(param)) -> None',
argNames=('texunit','target','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexEnvfvEXT = platform.createExtensionFunction( 
'glMultiTexEnvfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexEnvfvEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexEnviEXT = platform.createExtensionFunction( 
'glMultiTexEnviEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLint,),
doc='glMultiTexEnviEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLint(param)) -> None',
argNames=('texunit','target','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexEnvivEXT = platform.createExtensionFunction( 
'glMultiTexEnvivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glMultiTexEnvivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexGendEXT = platform.createExtensionFunction( 
'glMultiTexGendEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLdouble,),
doc='glMultiTexGendEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLdouble(param)) -> None',
argNames=('texunit','coord','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexGendvEXT = platform.createExtensionFunction( 
'glMultiTexGendvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLdoubleArray,),
doc='glMultiTexGendvEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLdoubleArray(params)) -> None',
argNames=('texunit','coord','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexGenfEXT = platform.createExtensionFunction( 
'glMultiTexGenfEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLfloat,),
doc='glMultiTexGenfEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLfloat(param)) -> None',
argNames=('texunit','coord','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexGenfvEXT = platform.createExtensionFunction( 
'glMultiTexGenfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexGenfvEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','coord','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexGeniEXT = platform.createExtensionFunction( 
'glMultiTexGeniEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLint,),
doc='glMultiTexGeniEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLint(param)) -> None',
argNames=('texunit','coord','pname','param',),
deprecated=_DEPRECATED,
)

glMultiTexGenivEXT = platform.createExtensionFunction( 
'glMultiTexGenivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glMultiTexGenivEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','coord','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexEnvfvEXT = platform.createExtensionFunction( 
'glGetMultiTexEnvfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetMultiTexEnvfvEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexEnvivEXT = platform.createExtensionFunction( 
'glGetMultiTexEnvivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetMultiTexEnvivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexGendvEXT = platform.createExtensionFunction( 
'glGetMultiTexGendvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLdoubleArray,),
doc='glGetMultiTexGendvEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLdoubleArray(params)) -> None',
argNames=('texunit','coord','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexGenfvEXT = platform.createExtensionFunction( 
'glGetMultiTexGenfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetMultiTexGenfvEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('texunit','coord','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexGenivEXT = platform.createExtensionFunction( 
'glGetMultiTexGenivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetMultiTexGenivEXT(GLenum(texunit), GLenum(coord), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','coord','pname','params',),
deprecated=_DEPRECATED,
)

glGetFloatIndexedvEXT = platform.createExtensionFunction( 
'glGetFloatIndexedvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLfloatArray,),
doc='glGetFloatIndexedvEXT(GLenum(target), GLuint(index), GLfloatArray(data)) -> None',
argNames=('target','index','data',),
deprecated=_DEPRECATED,
)

glGetDoubleIndexedvEXT = platform.createExtensionFunction( 
'glGetDoubleIndexedvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLdoubleArray,),
doc='glGetDoubleIndexedvEXT(GLenum(target), GLuint(index), GLdoubleArray(data)) -> None',
argNames=('target','index','data',),
deprecated=_DEPRECATED,
)

glGetPointerIndexedvEXT = platform.createExtensionFunction( 
'glGetPointerIndexedvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,ctypes.POINTER(ctypes.c_void_p),),
doc='glGetPointerIndexedvEXT(GLenum(target), GLuint(index), POINTER(ctypes.c_void_p)(data)) -> None',
argNames=('target','index','data',),
deprecated=_DEPRECATED,
)

glCompressedTextureImage3DEXT = platform.createExtensionFunction( 
'glCompressedTextureImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTextureImage3DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texture','target','level','internalformat','width','height','depth','border','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedTextureImage2DEXT = platform.createExtensionFunction( 
'glCompressedTextureImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTextureImage2DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLint(border), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texture','target','level','internalformat','width','height','border','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedTextureImage1DEXT = platform.createExtensionFunction( 
'glCompressedTextureImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTextureImage1DEXT(GLuint(texture), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLint(border), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texture','target','level','internalformat','width','border','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedTextureSubImage3DEXT = platform.createExtensionFunction( 
'glCompressedTextureSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTextureSubImage3DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texture','target','level','xoffset','yoffset','zoffset','width','height','depth','format','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedTextureSubImage2DEXT = platform.createExtensionFunction( 
'glCompressedTextureSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTextureSubImage2DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texture','target','level','xoffset','yoffset','width','height','format','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedTextureSubImage1DEXT = platform.createExtensionFunction( 
'glCompressedTextureSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTextureSubImage1DEXT(GLuint(texture), GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texture','target','level','xoffset','width','format','imageSize','bits',),
deprecated=_DEPRECATED,
)

glGetCompressedTextureImageEXT = platform.createExtensionFunction( 
'glGetCompressedTextureImageEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,ctypes.c_void_p,),
doc='glGetCompressedTextureImageEXT(GLuint(texture), GLenum(target), GLint(lod), c_void_p(img)) -> None',
argNames=('texture','target','lod','img',),
deprecated=_DEPRECATED,
)

glCompressedMultiTexImage3DEXT = platform.createExtensionFunction( 
'glCompressedMultiTexImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedMultiTexImage3DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texunit','target','level','internalformat','width','height','depth','border','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedMultiTexImage2DEXT = platform.createExtensionFunction( 
'glCompressedMultiTexImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedMultiTexImage2DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLint(border), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texunit','target','level','internalformat','width','height','border','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedMultiTexImage1DEXT = platform.createExtensionFunction( 
'glCompressedMultiTexImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedMultiTexImage1DEXT(GLenum(texunit), GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLint(border), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texunit','target','level','internalformat','width','border','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedMultiTexSubImage3DEXT = platform.createExtensionFunction( 
'glCompressedMultiTexSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedMultiTexSubImage3DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texunit','target','level','xoffset','yoffset','zoffset','width','height','depth','format','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedMultiTexSubImage2DEXT = platform.createExtensionFunction( 
'glCompressedMultiTexSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedMultiTexSubImage2DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texunit','target','level','xoffset','yoffset','width','height','format','imageSize','bits',),
deprecated=_DEPRECATED,
)

glCompressedMultiTexSubImage1DEXT = platform.createExtensionFunction( 
'glCompressedMultiTexSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedMultiTexSubImage1DEXT(GLenum(texunit), GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLsizei(imageSize), c_void_p(bits)) -> None',
argNames=('texunit','target','level','xoffset','width','format','imageSize','bits',),
deprecated=_DEPRECATED,
)

glGetCompressedMultiTexImageEXT = platform.createExtensionFunction( 
'glGetCompressedMultiTexImageEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,ctypes.c_void_p,),
doc='glGetCompressedMultiTexImageEXT(GLenum(texunit), GLenum(target), GLint(lod), c_void_p(img)) -> None',
argNames=('texunit','target','lod','img',),
deprecated=_DEPRECATED,
)

glNamedProgramStringEXT = platform.createExtensionFunction( 
'glNamedProgramStringEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glNamedProgramStringEXT(GLuint(program), GLenum(target), GLenum(format), GLsizei(len), c_void_p(string)) -> None',
argNames=('program','target','format','len','string',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameter4dEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameter4dEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glNamedProgramLocalParameter4dEXT(GLuint(program), GLenum(target), GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z), GLdouble(w)) -> None',
argNames=('program','target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameter4dvEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameter4dvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLdoubleArray,),
doc='glNamedProgramLocalParameter4dvEXT(GLuint(program), GLenum(target), GLuint(index), GLdoubleArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameter4fEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameter4fEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glNamedProgramLocalParameter4fEXT(GLuint(program), GLenum(target), GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w)) -> None',
argNames=('program','target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameter4fvEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameter4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLfloatArray,),
doc='glNamedProgramLocalParameter4fvEXT(GLuint(program), GLenum(target), GLuint(index), GLfloatArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glGetNamedProgramLocalParameterdvEXT = platform.createExtensionFunction( 
'glGetNamedProgramLocalParameterdvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLdoubleArray,),
doc='glGetNamedProgramLocalParameterdvEXT(GLuint(program), GLenum(target), GLuint(index), GLdoubleArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glGetNamedProgramLocalParameterfvEXT = platform.createExtensionFunction( 
'glGetNamedProgramLocalParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLfloatArray,),
doc='glGetNamedProgramLocalParameterfvEXT(GLuint(program), GLenum(target), GLuint(index), GLfloatArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glGetNamedProgramivEXT = platform.createExtensionFunction( 
'glGetNamedProgramivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetNamedProgramivEXT(GLuint(program), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('program','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetNamedProgramStringEXT = platform.createExtensionFunction( 
'glGetNamedProgramStringEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glGetNamedProgramStringEXT(GLuint(program), GLenum(target), GLenum(pname), c_void_p(string)) -> None',
argNames=('program','target','pname','string',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameters4fvEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameters4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLfloatArray,),
doc='glNamedProgramLocalParameters4fvEXT(GLuint(program), GLenum(target), GLuint(index), GLsizei(count), GLfloatArray(params)) -> None',
argNames=('program','target','index','count','params',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameterI4iEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameterI4iEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glNamedProgramLocalParameterI4iEXT(GLuint(program), GLenum(target), GLuint(index), GLint(x), GLint(y), GLint(z), GLint(w)) -> None',
argNames=('program','target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameterI4ivEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameterI4ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glNamedProgramLocalParameterI4ivEXT(GLuint(program), GLenum(target), GLuint(index), GLintArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParametersI4ivEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParametersI4ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLintArray,),
doc='glNamedProgramLocalParametersI4ivEXT(GLuint(program), GLenum(target), GLuint(index), GLsizei(count), GLintArray(params)) -> None',
argNames=('program','target','index','count','params',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameterI4uiEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameterI4uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glNamedProgramLocalParameterI4uiEXT(GLuint(program), GLenum(target), GLuint(index), GLuint(x), GLuint(y), GLuint(z), GLuint(w)) -> None',
argNames=('program','target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParameterI4uivEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParameterI4uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLuintArray,),
doc='glNamedProgramLocalParameterI4uivEXT(GLuint(program), GLenum(target), GLuint(index), GLuintArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glNamedProgramLocalParametersI4uivEXT = platform.createExtensionFunction( 
'glNamedProgramLocalParametersI4uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLuintArray,),
doc='glNamedProgramLocalParametersI4uivEXT(GLuint(program), GLenum(target), GLuint(index), GLsizei(count), GLuintArray(params)) -> None',
argNames=('program','target','index','count','params',),
deprecated=_DEPRECATED,
)

glGetNamedProgramLocalParameterIivEXT = platform.createExtensionFunction( 
'glGetNamedProgramLocalParameterIivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glGetNamedProgramLocalParameterIivEXT(GLuint(program), GLenum(target), GLuint(index), GLintArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glGetNamedProgramLocalParameterIuivEXT = platform.createExtensionFunction( 
'glGetNamedProgramLocalParameterIuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,arrays.GLuintArray,),
doc='glGetNamedProgramLocalParameterIuivEXT(GLuint(program), GLenum(target), GLuint(index), GLuintArray(params)) -> None',
argNames=('program','target','index','params',),
deprecated=_DEPRECATED,
)

glTextureParameterIivEXT = platform.createExtensionFunction( 
'glTextureParameterIivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glTextureParameterIivEXT(GLuint(texture), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glTextureParameterIuivEXT = platform.createExtensionFunction( 
'glTextureParameterIuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLuintArray,),
doc='glTextureParameterIuivEXT(GLuint(texture), GLenum(target), GLenum(pname), GLuintArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetTextureParameterIivEXT = platform.createExtensionFunction( 
'glGetTextureParameterIivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetTextureParameterIivEXT(GLuint(texture), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetTextureParameterIuivEXT = platform.createExtensionFunction( 
'glGetTextureParameterIuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLuintArray,),
doc='glGetTextureParameterIuivEXT(GLuint(texture), GLenum(target), GLenum(pname), GLuintArray(params)) -> None',
argNames=('texture','target','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexParameterIivEXT = platform.createExtensionFunction( 
'glMultiTexParameterIivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glMultiTexParameterIivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glMultiTexParameterIuivEXT = platform.createExtensionFunction( 
'glMultiTexParameterIuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLuintArray,),
doc='glMultiTexParameterIuivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLuintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexParameterIivEXT = platform.createExtensionFunction( 
'glGetMultiTexParameterIivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetMultiTexParameterIivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMultiTexParameterIuivEXT = platform.createExtensionFunction( 
'glGetMultiTexParameterIuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLuintArray,),
doc='glGetMultiTexParameterIuivEXT(GLenum(texunit), GLenum(target), GLenum(pname), GLuintArray(params)) -> None',
argNames=('texunit','target','pname','params',),
deprecated=_DEPRECATED,
)

glProgramUniform1fEXT = platform.createExtensionFunction( 
'glProgramUniform1fEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLfloat,),
doc='glProgramUniform1fEXT(GLuint(program), GLint(location), GLfloat(v0)) -> None',
argNames=('program','location','v0',),
deprecated=_DEPRECATED,
)

glProgramUniform2fEXT = platform.createExtensionFunction( 
'glProgramUniform2fEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLfloat,constants.GLfloat,),
doc='glProgramUniform2fEXT(GLuint(program), GLint(location), GLfloat(v0), GLfloat(v1)) -> None',
argNames=('program','location','v0','v1',),
deprecated=_DEPRECATED,
)

glProgramUniform3fEXT = platform.createExtensionFunction( 
'glProgramUniform3fEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glProgramUniform3fEXT(GLuint(program), GLint(location), GLfloat(v0), GLfloat(v1), GLfloat(v2)) -> None',
argNames=('program','location','v0','v1','v2',),
deprecated=_DEPRECATED,
)

glProgramUniform4fEXT = platform.createExtensionFunction( 
'glProgramUniform4fEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glProgramUniform4fEXT(GLuint(program), GLint(location), GLfloat(v0), GLfloat(v1), GLfloat(v2), GLfloat(v3)) -> None',
argNames=('program','location','v0','v1','v2','v3',),
deprecated=_DEPRECATED,
)

glProgramUniform1iEXT = platform.createExtensionFunction( 
'glProgramUniform1iEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLint,),
doc='glProgramUniform1iEXT(GLuint(program), GLint(location), GLint(v0)) -> None',
argNames=('program','location','v0',),
deprecated=_DEPRECATED,
)

glProgramUniform2iEXT = platform.createExtensionFunction( 
'glProgramUniform2iEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLint,constants.GLint,),
doc='glProgramUniform2iEXT(GLuint(program), GLint(location), GLint(v0), GLint(v1)) -> None',
argNames=('program','location','v0','v1',),
deprecated=_DEPRECATED,
)

glProgramUniform3iEXT = platform.createExtensionFunction( 
'glProgramUniform3iEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glProgramUniform3iEXT(GLuint(program), GLint(location), GLint(v0), GLint(v1), GLint(v2)) -> None',
argNames=('program','location','v0','v1','v2',),
deprecated=_DEPRECATED,
)

glProgramUniform4iEXT = platform.createExtensionFunction( 
'glProgramUniform4iEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glProgramUniform4iEXT(GLuint(program), GLint(location), GLint(v0), GLint(v1), GLint(v2), GLint(v3)) -> None',
argNames=('program','location','v0','v1','v2','v3',),
deprecated=_DEPRECATED,
)

glProgramUniform1fvEXT = platform.createExtensionFunction( 
'glProgramUniform1fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLfloatArray,),
doc='glProgramUniform1fvEXT(GLuint(program), GLint(location), GLsizei(count), GLfloatArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform2fvEXT = platform.createExtensionFunction( 
'glProgramUniform2fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLfloatArray,),
doc='glProgramUniform2fvEXT(GLuint(program), GLint(location), GLsizei(count), GLfloatArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform3fvEXT = platform.createExtensionFunction( 
'glProgramUniform3fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLfloatArray,),
doc='glProgramUniform3fvEXT(GLuint(program), GLint(location), GLsizei(count), GLfloatArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform4fvEXT = platform.createExtensionFunction( 
'glProgramUniform4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLfloatArray,),
doc='glProgramUniform4fvEXT(GLuint(program), GLint(location), GLsizei(count), GLfloatArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform1ivEXT = platform.createExtensionFunction( 
'glProgramUniform1ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLintArray,),
doc='glProgramUniform1ivEXT(GLuint(program), GLint(location), GLsizei(count), GLintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform2ivEXT = platform.createExtensionFunction( 
'glProgramUniform2ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLintArray,),
doc='glProgramUniform2ivEXT(GLuint(program), GLint(location), GLsizei(count), GLintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform3ivEXT = platform.createExtensionFunction( 
'glProgramUniform3ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLintArray,),
doc='glProgramUniform3ivEXT(GLuint(program), GLint(location), GLsizei(count), GLintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform4ivEXT = platform.createExtensionFunction( 
'glProgramUniform4ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLintArray,),
doc='glProgramUniform4ivEXT(GLuint(program), GLint(location), GLsizei(count), GLintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix2fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix2fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix2fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix3fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix3fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix3fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix4fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix4fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix2x3fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix2x3fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix2x3fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix3x2fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix3x2fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix3x2fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix2x4fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix2x4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix2x4fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix4x2fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix4x2fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix4x2fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix3x4fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix3x4fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix3x4fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniformMatrix4x3fvEXT = platform.createExtensionFunction( 
'glProgramUniformMatrix4x3fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glProgramUniformMatrix4x3fvEXT(GLuint(program), GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('program','location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glProgramUniform1uiEXT = platform.createExtensionFunction( 
'glProgramUniform1uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLuint,),
doc='glProgramUniform1uiEXT(GLuint(program), GLint(location), GLuint(v0)) -> None',
argNames=('program','location','v0',),
deprecated=_DEPRECATED,
)

glProgramUniform2uiEXT = platform.createExtensionFunction( 
'glProgramUniform2uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLuint,constants.GLuint,),
doc='glProgramUniform2uiEXT(GLuint(program), GLint(location), GLuint(v0), GLuint(v1)) -> None',
argNames=('program','location','v0','v1',),
deprecated=_DEPRECATED,
)

glProgramUniform3uiEXT = platform.createExtensionFunction( 
'glProgramUniform3uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glProgramUniform3uiEXT(GLuint(program), GLint(location), GLuint(v0), GLuint(v1), GLuint(v2)) -> None',
argNames=('program','location','v0','v1','v2',),
deprecated=_DEPRECATED,
)

glProgramUniform4uiEXT = platform.createExtensionFunction( 
'glProgramUniform4uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glProgramUniform4uiEXT(GLuint(program), GLint(location), GLuint(v0), GLuint(v1), GLuint(v2), GLuint(v3)) -> None',
argNames=('program','location','v0','v1','v2','v3',),
deprecated=_DEPRECATED,
)

glProgramUniform1uivEXT = platform.createExtensionFunction( 
'glProgramUniform1uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glProgramUniform1uivEXT(GLuint(program), GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform2uivEXT = platform.createExtensionFunction( 
'glProgramUniform2uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glProgramUniform2uivEXT(GLuint(program), GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform3uivEXT = platform.createExtensionFunction( 
'glProgramUniform3uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glProgramUniform3uivEXT(GLuint(program), GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glProgramUniform4uivEXT = platform.createExtensionFunction( 
'glProgramUniform4uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glProgramUniform4uivEXT(GLuint(program), GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)

glNamedBufferDataEXT = platform.createExtensionFunction( 
'glNamedBufferDataEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizeiptr,ctypes.c_void_p,constants.GLenum,),
doc='glNamedBufferDataEXT(GLuint(buffer), GLsizeiptr(size), c_void_p(data), GLenum(usage)) -> None',
argNames=('buffer','size','data','usage',),
deprecated=_DEPRECATED,
)

glNamedBufferSubDataEXT = platform.createExtensionFunction( 
'glNamedBufferSubDataEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLintptr,constants.GLsizeiptr,ctypes.c_void_p,),
doc='glNamedBufferSubDataEXT(GLuint(buffer), GLintptr(offset), GLsizeiptr(size), c_void_p(data)) -> None',
argNames=('buffer','offset','size','data',),
deprecated=_DEPRECATED,
)

glMapNamedBufferEXT = platform.createExtensionFunction( 
'glMapNamedBufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=ctypes.c_void_p, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glMapNamedBufferEXT(GLuint(buffer), GLenum(access)) -> ctypes.c_void_p',
argNames=('buffer','access',),
deprecated=_DEPRECATED,
)

glUnmapNamedBufferEXT = platform.createExtensionFunction( 
'glUnmapNamedBufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glUnmapNamedBufferEXT(GLuint(buffer)) -> constants.GLboolean',
argNames=('buffer',),
deprecated=_DEPRECATED,
)

glGetNamedBufferParameterivEXT = platform.createExtensionFunction( 
'glGetNamedBufferParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetNamedBufferParameterivEXT(GLuint(buffer), GLenum(pname), GLintArray(params)) -> None',
argNames=('buffer','pname','params',),
deprecated=_DEPRECATED,
)

glGetNamedBufferPointervEXT = platform.createExtensionFunction( 
'glGetNamedBufferPointervEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,ctypes.POINTER(ctypes.c_void_p),),
doc='glGetNamedBufferPointervEXT(GLuint(buffer), GLenum(pname), POINTER(ctypes.c_void_p)(params)) -> None',
argNames=('buffer','pname','params',),
deprecated=_DEPRECATED,
)

glGetNamedBufferSubDataEXT = platform.createExtensionFunction( 
'glGetNamedBufferSubDataEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLintptr,constants.GLsizeiptr,ctypes.c_void_p,),
doc='glGetNamedBufferSubDataEXT(GLuint(buffer), GLintptr(offset), GLsizeiptr(size), c_void_p(data)) -> None',
argNames=('buffer','offset','size','data',),
deprecated=_DEPRECATED,
)

glTextureBufferEXT = platform.createExtensionFunction( 
'glTextureBufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glTextureBufferEXT(GLuint(texture), GLenum(target), GLenum(internalformat), GLuint(buffer)) -> None',
argNames=('texture','target','internalformat','buffer',),
deprecated=_DEPRECATED,
)

glMultiTexBufferEXT = platform.createExtensionFunction( 
'glMultiTexBufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glMultiTexBufferEXT(GLenum(texunit), GLenum(target), GLenum(internalformat), GLuint(buffer)) -> None',
argNames=('texunit','target','internalformat','buffer',),
deprecated=_DEPRECATED,
)

glNamedRenderbufferStorageEXT = platform.createExtensionFunction( 
'glNamedRenderbufferStorageEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLsizei,constants.GLsizei,),
doc='glNamedRenderbufferStorageEXT(GLuint(renderbuffer), GLenum(internalformat), GLsizei(width), GLsizei(height)) -> None',
argNames=('renderbuffer','internalformat','width','height',),
deprecated=_DEPRECATED,
)

glGetNamedRenderbufferParameterivEXT = platform.createExtensionFunction( 
'glGetNamedRenderbufferParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetNamedRenderbufferParameterivEXT(GLuint(renderbuffer), GLenum(pname), GLintArray(params)) -> None',
argNames=('renderbuffer','pname','params',),
deprecated=_DEPRECATED,
)

glCheckNamedFramebufferStatusEXT = platform.createExtensionFunction( 
'glCheckNamedFramebufferStatusEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLenum, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glCheckNamedFramebufferStatusEXT(GLuint(framebuffer), GLenum(target)) -> constants.GLenum',
argNames=('framebuffer','target',),
deprecated=_DEPRECATED,
)

glNamedFramebufferTexture1DEXT = platform.createExtensionFunction( 
'glNamedFramebufferTexture1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,),
doc='glNamedFramebufferTexture1DEXT(GLuint(framebuffer), GLenum(attachment), GLenum(textarget), GLuint(texture), GLint(level)) -> None',
argNames=('framebuffer','attachment','textarget','texture','level',),
deprecated=_DEPRECATED,
)

glNamedFramebufferTexture2DEXT = platform.createExtensionFunction( 
'glNamedFramebufferTexture2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,),
doc='glNamedFramebufferTexture2DEXT(GLuint(framebuffer), GLenum(attachment), GLenum(textarget), GLuint(texture), GLint(level)) -> None',
argNames=('framebuffer','attachment','textarget','texture','level',),
deprecated=_DEPRECATED,
)

glNamedFramebufferTexture3DEXT = platform.createExtensionFunction( 
'glNamedFramebufferTexture3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,),
doc='glNamedFramebufferTexture3DEXT(GLuint(framebuffer), GLenum(attachment), GLenum(textarget), GLuint(texture), GLint(level), GLint(zoffset)) -> None',
argNames=('framebuffer','attachment','textarget','texture','level','zoffset',),
deprecated=_DEPRECATED,
)

glNamedFramebufferRenderbufferEXT = platform.createExtensionFunction( 
'glNamedFramebufferRenderbufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glNamedFramebufferRenderbufferEXT(GLuint(framebuffer), GLenum(attachment), GLenum(renderbuffertarget), GLuint(renderbuffer)) -> None',
argNames=('framebuffer','attachment','renderbuffertarget','renderbuffer',),
deprecated=_DEPRECATED,
)

glGetNamedFramebufferAttachmentParameterivEXT = platform.createExtensionFunction( 
'glGetNamedFramebufferAttachmentParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetNamedFramebufferAttachmentParameterivEXT(GLuint(framebuffer), GLenum(attachment), GLenum(pname), GLintArray(params)) -> None',
argNames=('framebuffer','attachment','pname','params',),
deprecated=_DEPRECATED,
)

glGenerateTextureMipmapEXT = platform.createExtensionFunction( 
'glGenerateTextureMipmapEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glGenerateTextureMipmapEXT(GLuint(texture), GLenum(target)) -> None',
argNames=('texture','target',),
deprecated=_DEPRECATED,
)

glGenerateMultiTexMipmapEXT = platform.createExtensionFunction( 
'glGenerateMultiTexMipmapEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glGenerateMultiTexMipmapEXT(GLenum(texunit), GLenum(target)) -> None',
argNames=('texunit','target',),
deprecated=_DEPRECATED,
)

glFramebufferDrawBufferEXT = platform.createExtensionFunction( 
'glFramebufferDrawBufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glFramebufferDrawBufferEXT(GLuint(framebuffer), GLenum(mode)) -> None',
argNames=('framebuffer','mode',),
deprecated=_DEPRECATED,
)

glFramebufferDrawBuffersEXT = platform.createExtensionFunction( 
'glFramebufferDrawBuffersEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLuintArray,),
doc='glFramebufferDrawBuffersEXT(GLuint(framebuffer), GLsizei(n), GLuintArray(bufs)) -> None',
argNames=('framebuffer','n','bufs',),
deprecated=_DEPRECATED,
)

glFramebufferReadBufferEXT = platform.createExtensionFunction( 
'glFramebufferReadBufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glFramebufferReadBufferEXT(GLuint(framebuffer), GLenum(mode)) -> None',
argNames=('framebuffer','mode',),
deprecated=_DEPRECATED,
)

glGetFramebufferParameterivEXT = platform.createExtensionFunction( 
'glGetFramebufferParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetFramebufferParameterivEXT(GLuint(framebuffer), GLenum(pname), GLintArray(params)) -> None',
argNames=('framebuffer','pname','params',),
deprecated=_DEPRECATED,
)

glNamedRenderbufferStorageMultisampleEXT = platform.createExtensionFunction( 
'glNamedRenderbufferStorageMultisampleEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,constants.GLenum,constants.GLsizei,constants.GLsizei,),
doc='glNamedRenderbufferStorageMultisampleEXT(GLuint(renderbuffer), GLsizei(samples), GLenum(internalformat), GLsizei(width), GLsizei(height)) -> None',
argNames=('renderbuffer','samples','internalformat','width','height',),
deprecated=_DEPRECATED,
)

glNamedRenderbufferStorageMultisampleCoverageEXT = platform.createExtensionFunction( 
'glNamedRenderbufferStorageMultisampleCoverageEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,constants.GLsizei,),
doc='glNamedRenderbufferStorageMultisampleCoverageEXT(GLuint(renderbuffer), GLsizei(coverageSamples), GLsizei(colorSamples), GLenum(internalformat), GLsizei(width), GLsizei(height)) -> None',
argNames=('renderbuffer','coverageSamples','colorSamples','internalformat','width','height',),
deprecated=_DEPRECATED,
)

glNamedFramebufferTextureEXT = platform.createExtensionFunction( 
'glNamedFramebufferTextureEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLint,),
doc='glNamedFramebufferTextureEXT(GLuint(framebuffer), GLenum(attachment), GLuint(texture), GLint(level)) -> None',
argNames=('framebuffer','attachment','texture','level',),
deprecated=_DEPRECATED,
)

glNamedFramebufferTextureLayerEXT = platform.createExtensionFunction( 
'glNamedFramebufferTextureLayerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,),
doc='glNamedFramebufferTextureLayerEXT(GLuint(framebuffer), GLenum(attachment), GLuint(texture), GLint(level), GLint(layer)) -> None',
argNames=('framebuffer','attachment','texture','level','layer',),
deprecated=_DEPRECATED,
)

glNamedFramebufferTextureFaceEXT = platform.createExtensionFunction( 
'glNamedFramebufferTextureFaceEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,constants.GLint,constants.GLenum,),
doc='glNamedFramebufferTextureFaceEXT(GLuint(framebuffer), GLenum(attachment), GLuint(texture), GLint(level), GLenum(face)) -> None',
argNames=('framebuffer','attachment','texture','level','face',),
deprecated=_DEPRECATED,
)

glTextureRenderbufferEXT = platform.createExtensionFunction( 
'glTextureRenderbufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,),
doc='glTextureRenderbufferEXT(GLuint(texture), GLenum(target), GLuint(renderbuffer)) -> None',
argNames=('texture','target','renderbuffer',),
deprecated=_DEPRECATED,
)

glMultiTexRenderbufferEXT = platform.createExtensionFunction( 
'glMultiTexRenderbufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glMultiTexRenderbufferEXT(GLenum(texunit), GLenum(target), GLuint(renderbuffer)) -> None',
argNames=('texunit','target','renderbuffer',),
deprecated=_DEPRECATED,
)


def glInitDirectStateAccessEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



"""Exceptional cases that need some extra wrapping"""
from OpenGL.platform import GL,GLU,createBaseFunction
from OpenGL import arrays, error, wrapper
from OpenGL.arrays.arraydatatype import GLfloatArray, GLdoubleArray
from OpenGL import constants as data_types
from OpenGL.lazywrapper import lazy
from OpenGL.raw import GL as simple
from OpenGL.raw.GL import constants
from OpenGL.raw.GL import annotations
import OpenGL
import ctypes

__all__ = [
    'glBegin',
    'glCallLists',
    'glColor',
    #'glColorTableParameterfv',
    'glDeleteTextures',
    'glEdgeFlagv',
    'glEnd',
    'glGenTextures',
    'glIndexdv',
    'glIndexfv',
    'glIndexsv',
    'glIndexubv',
    'glMap1d',
    'glMap1f',
    'glMap2d',
    'glMap2f',
    'glMaterial',
    'glRasterPos',
    'glRectfv',
    'glRectiv',
    'glRectsv',
    'glTexGenfv',
    'glTexParameter',
    'glVertex',
    'glAreTexturesResident',
]

glRasterPosDispatch = {
    2: simple.glRasterPos2d,
    3: simple.glRasterPos3d,
    4: simple.glRasterPos4d,
}

if OpenGL.ERROR_CHECKING:
    @lazy( simple.glBegin )
    def glBegin( baseFunction, mode ):
        """Begin GL geometry-definition mode, disable automatic error checking"""
        error.onBegin( )
        return baseFunction( mode )
    @lazy( simple.glEnd )
    def glEnd( baseFunction ):
        """Finish GL geometry-definition mode, re-enable automatic error checking"""
        error.onEnd( )
        return baseFunction( )
else:
    glBegin = simple.glBegin
    glEnd = simple.glEnd

@lazy( simple.glDeleteTextures )
def glDeleteTextures( baseFunction, array ):
    """Delete specified set of textures"""
    ptr = arrays.GLuintArray.asArray( array )
    size = arrays.GLuintArray.arraySize( ptr )
    return baseFunction( size, ptr )


def glMap2( baseFunction, arrayType ):
    def glMap2( target, u1, u2, v1, v2, points):
        """glMap2(target, u1, u2, v1, v2, points[][][]) -> None

        This is a completely non-standard signature which doesn't allow for most
        of the funky uses with strides and the like, but it has been like this for
        a very long time...
        """
        ptr = arrayType.asArray( points )
        uorder,vorder,vstride = arrayType.dimensions( ptr )
        ustride = vstride*vorder
        return baseFunction(
            target,
            u1, u2,
            ustride, uorder,
            v1, v2,
            vstride, vorder,
            ptr
        )
    glMap2.__name__ = baseFunction.__name__
    glMap2.baseFunction = baseFunction
    return glMap2
glMap2d = glMap2( simple.glMap2d, arrays.GLdoubleArray )
glMap2f = glMap2( simple.glMap2f, arrays.GLfloatArray )
del glMap2

def glMap1( baseFunction, arrayType ):
    def glMap1(target,u1,u2,points):
        """glMap1(target, u1, u2, points[][][]) -> None

        This is a completely non-standard signature which doesn't allow for most
        of the funky uses with strides and the like, but it has been like this for
        a very long time...
        """
        ptr = arrayType.asArray( points )
        dims = arrayType.dimensions( ptr )
        uorder = dims[0]
        ustride = dims[1]
        return baseFunction( target, u1,u2,ustride,uorder, ptr )
    glMap1.__name__ == baseFunction.__name__
    glMap1.baseFunction = baseFunction
    return glMap1
glMap1d = glMap1( simple.glMap1d, arrays.GLdoubleArray )
glMap1f = glMap1( simple.glMap1f, arrays.GLfloatArray )
del glMap1

def glRasterPos( *args ):
    """Choose glRasterPosX based on number of args"""
    if len(args) == 1:
        # v form...
        args = args[0]
    return glRasterPosDispatch[ len(args) ]( *args )

glVertexDispatch = {
    2: simple.glVertex2d,
    3: simple.glVertex3d,
    4: simple.glVertex4d,
}
def glVertex( *args ):
    """Choose glVertexX based on number of args"""
    if len(args) == 1:
        # v form...
        args = args[0]
    return glVertexDispatch[ len(args) ]( *args )

@lazy( simple.glCallLists )
def glCallLists( baseFunction, lists, *args ):
    """glCallLists( str( lists ) or lists[] ) -> None

    Restricted version of glCallLists, takes a string or a GLuint compatible
    array data-type and passes into the base function.
    """
    if not len(args):
        if isinstance( lists, str ):
            return baseFunction(
                len(lists),
                constants.GL_UNSIGNED_BYTE,
                ctypes.c_void_p(arrays.GLubyteArray.dataPointer( lists )),
            )
        ptr = arrays.GLuintArray.asArray( lists )
        size = arrays.GLuintArray.arraySize( ptr )
        return baseFunction(
            size,
            constants.GL_UNSIGNED_INT,
            ctypes.c_void_p( arrays.GLuintArray.dataPointer(ptr))
        )
    return baseFunction( lists, *args )

def glTexParameter( target, pname, parameter ):
    """Set a texture parameter, choose underlying call based on pname and parameter"""
    if isinstance( parameter, float ):
        return simple.glTexParameterf( target, pname, parameter )
    elif isinstance( parameter, int ):
        return simple.glTexParameteri( target, pname, parameter )
    else:
        value = GLfloatArray.asArray( parameter, constants.GL_FLOAT )
        return simple.glTexParameterfv( target, pname, value )

@lazy( simple.glGenTextures )
def glGenTextures( baseFunction, count, textures=None ):
    """Generate count new texture names

    Note: for compatibility with PyOpenGL 2.x and below,
    a count of 1 will return a single integer, rather than
    an array of integers.
    """
    if count <= 0:
        raise ValueError( """Can't generate 0 or fewer textures""" )
    elif count == 1 and OpenGL.SIZE_1_ARRAY_UNPACK:
        # this traditionally returned a single int/long, so we'll continue to
        # do so, even though it would be easier not to bother.
        textures = simple.GLuint( 0 )
        baseFunction( count, textures)
        return textures.value
    else:
        textures = arrays.GLuintArray.zeros( (count,))
        baseFunction( count, textures)
        return textures

def glMaterial( faces, constant, *args ):
    """glMaterial -- convenience function to dispatch on argument type

    If passed a single argument in args, calls:
        glMaterialfv( faces, constant, args[0] )
    else calls:
        glMaterialf( faces, constant, *args )
    """
    if len(args) == 1:
        arg = GLfloatArray.asArray( args[0] )
        if arg is None:
            raise ValueError( """Null value in glMaterial: %s"""%(args,) )
        return simple.glMaterialfv( faces, constant, arg )
    else:
        return simple.glMaterialf( faces, constant, *args )

glColorDispatch = {
    3: annotations.glColor3fv,
    4: annotations.glColor4fv,
}

def glColor( *args ):
    """glColor*f* -- convenience function to dispatch on argument type

    dispatches to glColor3f, glColor2f, glColor4f, glColor3f, glColor2f, glColor4f
    depending on the arguments passed...
    """
    arglen = len(args)
    if arglen == 1:
        arg = arrays.GLfloatArray.asArray( args[0] )
        function = glColorDispatch[arrays.GLfloatArray.arraySize( arg )]
        return function( arg )
    elif arglen == 2:
        return simple.glColor2d( *args )
    elif arglen == 3:
        return simple.glColor3d( *args )
    elif arglen == 4:
        return simple.glColor4d( *args )
    else:
        raise ValueError( """Don't know how to handle arguments: %s"""%(args,))


# Rectagle coordinates,
glRectfv = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        simple.glRectfv,
        2,
        arrays.GLfloatArray,
        'v1',
    ),
    2,
    arrays.GLfloatArray,
    'v2',
)
glRectiv = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        simple.glRectiv,
        2,
        arrays.GLintArray,
        'v1',
    ),
    2,
    arrays.GLintArray,
    'v2',
)
glRectsv = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        simple.glRectsv,
        2,
        arrays.GLshortArray,
        'v1',
    ),
    2,
    arrays.GLshortArray,
    'v2',
)


glIndexsv = arrays.setInputArraySizeType(
    simple.glIndexsv,
    1,
    arrays.GLshortArray,
    'c',
)
glIndexdv = arrays.setInputArraySizeType(
    simple.glIndexdv,
    1,
    arrays.GLdoubleArray,
    'c',
)
glIndexfv = arrays.setInputArraySizeType(
    simple.glIndexfv,
    1,
    arrays.GLfloatArray,
    'c',
)
glIndexubv = arrays.setInputArraySizeType(
    simple.glIndexubv,
    1,
    arrays.GLbyteArray,
    'c',
)
glEdgeFlagv = arrays.setInputArraySizeType(
    simple.glEdgeFlagv,
    1,
    arrays.GLubyteArray,
    'flag',
)
glTexGenfv = arrays.setInputArraySizeType(
    simple.glTexGenfv,
    None,
    arrays.GLfloatArray,
    'params',
)

#'glAreTexturesResident',
@lazy( simple.glAreTexturesResident )
def glAreTexturesResident( baseFunction, *args ):
    """Allow both Pythonic and C-style calls to glAreTexturesResident

        glAreTexturesResident( arrays.GLuintArray( textures) )

    or

        glAreTexturesResident( int(n), arrays.GLuintArray( textures), arrays.GLuboolean( output) )

    or

        glAreTexturesResident( int(n), arrays.GLuintArray( textures) )

    returns the output arrays.GLubooleanArray
    """
    if len(args) == 1:
        # Pythonic form...
        textures = args[0]
        textures = arrays.GLuintArray.asArray( textures )
        n = arrays.GLuintArray.arraySize(textures)
        output = arrays.GLbooleanArray.zeros( (n,))
    elif len(args) == 2:
        try:
            n = int( args[0] )
        except TypeError, err:
            textures = args[0]
            textures = arrays.GLuintArray.asArray( textures )

            n = arrays.GLuintArray.arraySize(textures)
            output = args[1]
            output = arrays.GLbooleanArray.asArray( output )
        else:
            textures = args[1]
            textures = arrays.GLuintArray.asArray( textures )

            output = arrays.GLbooleanArray.zeros( (n,))
    elif len(args) == 3:
        n,textures,output = args
        textures = arrays.GLuintArray.asArray( textures )
        output = arrays.GLbooleanArray.asArray( output )
    else:
        raise TypeError( """Expected 1 to 3 arguments to glAreTexturesResident""" )
    texturePtr = arrays.GLuintArray.typedPointer( textures )
    outputPtr = arrays.GLbooleanArray.typedPointer( output )
    result = baseFunction( n, texturePtr, outputPtr )
    if result:
        # weirdness of the C api, doesn't produce values if all are true
        for i in range(len(output)):
            output[i] = 1
    return output

#glMap2f
#glMap2d
#glMap1f
#glMap1d
#glPixelMapusv
#glTexGenfv
#glLightfv
#glFeedbackBuffer
#glDrawRangeElements
#glSelectBuffer
#glAreTexturesResident
#glPixelMapfv
#glTexGeniv
#glClipPlane
#glTexParameterfv
#glTexParameteriv
#glReadPixels
#glConvolutionParameterfv
#glPolygonStipple
#glFogiv
#glTexEnviv
#glRectdv
#glMaterialiv
#glColorTable
#glColorTableParameteriv
#glIndexiv
#glLightModeliv
#glDrawElements
#glConvolutionFilter1D
#glCallLists



'''OpenGL extension SGIX.shadow

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_shadow'
_DEPRECATED = False
GL_TEXTURE_COMPARE_SGIX = constant.Constant( 'GL_TEXTURE_COMPARE_SGIX', 0x819A )
GL_TEXTURE_COMPARE_OPERATOR_SGIX = constant.Constant( 'GL_TEXTURE_COMPARE_OPERATOR_SGIX', 0x819B )
GL_TEXTURE_LEQUAL_R_SGIX = constant.Constant( 'GL_TEXTURE_LEQUAL_R_SGIX', 0x819C )
GL_TEXTURE_GEQUAL_R_SGIX = constant.Constant( 'GL_TEXTURE_GEQUAL_R_SGIX', 0x819D )


def glInitShadowSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.copy_image

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_copy_image'
_DEPRECATED = False

glCopyImageSubDataNV = platform.createExtensionFunction( 
'glCopyImageSubDataNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLuint,constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,),
doc='glCopyImageSubDataNV(GLuint(srcName), GLenum(srcTarget), GLint(srcLevel), GLint(srcX), GLint(srcY), GLint(srcZ), GLuint(dstName), GLenum(dstTarget), GLint(dstLevel), GLint(dstX), GLint(dstY), GLint(dstZ), GLsizei(width), GLsizei(height), GLsizei(depth)) -> None',
argNames=('srcName','srcTarget','srcLevel','srcX','srcY','srcZ','dstName','dstTarget','dstLevel','dstX','dstY','dstZ','width','height','depth',),
deprecated=_DEPRECATED,
)


def glInitCopyImageNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension HP.convolution_border_modes

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_HP_convolution_border_modes'
_DEPRECATED = False
GL_IGNORE_BORDER_HP = constant.Constant( 'GL_IGNORE_BORDER_HP', 0x8150 )
GL_CONSTANT_BORDER_HP = constant.Constant( 'GL_CONSTANT_BORDER_HP', 0x8151 )
GL_REPLICATE_BORDER_HP = constant.Constant( 'GL_REPLICATE_BORDER_HP', 0x8153 )
GL_CONVOLUTION_BORDER_COLOR_HP = constant.Constant( 'GL_CONVOLUTION_BORDER_COLOR_HP', 0x8154 )


def glInitConvolutionBorderModesHP():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGI.texture_color_table

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGI_texture_color_table'
_DEPRECATED = False
GL_TEXTURE_COLOR_TABLE_SGI = constant.Constant( 'GL_TEXTURE_COLOR_TABLE_SGI', 0x80BC )
glget.addGLGetConstant( GL_TEXTURE_COLOR_TABLE_SGI, (1,) )
GL_PROXY_TEXTURE_COLOR_TABLE_SGI = constant.Constant( 'GL_PROXY_TEXTURE_COLOR_TABLE_SGI', 0x80BD )


def glInitTextureColorTableSGI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



"""Version 1.2 Image-handling functions

Almost all of the 1.2 enhancements are image-handling-related,
so this is, most of the 1.2 wrapper code...

Note that the functions that manually wrap certain operations are
guarded by if simple.functionName checks, so that you can use
if functionName to see if the function is available at run-time.
"""
from OpenGL import wrapper, constants, arrays
from OpenGL.lazywrapper import lazy
from OpenGL.raw.GL.VERSION import GL_1_2 as simple
from OpenGL.raw.GL.ARB import imaging
from OpenGL.GL import images
import ctypes

glGetHistogramParameterfv = wrapper.wrapper(simple.glGetHistogramParameterfv).setOutput(
    "params",(1,), 
)
glGetHistogramParameteriv = wrapper.wrapper(simple.glGetHistogramParameteriv).setOutput(
    "params",(1,), 
)

for suffix,arrayConstant in [
    ('b', constants.GL_BYTE),
    ('f', constants.GL_FLOAT),
    ('i', constants.GL_INT),
    ('s', constants.GL_SHORT),
    ('ub', constants.GL_UNSIGNED_BYTE),
    ('ui', constants.GL_UNSIGNED_INT),
    ('us', constants.GL_UNSIGNED_SHORT),
]:
    for functionName in (
        'glTexImage3D',
        'glTexSubImage3D', # extension/1.2 standard
    ):
        functionName, function = images.typedImageFunction(
            suffix, arrayConstant, getattr(simple, functionName),
        )
        globals()[functionName] = function
        del function, functionName
    del suffix,arrayConstant

glTexImage3D = images.setDimensionsAsInts(
    images.setImageInput(
        simple.glTexImage3D,
        typeName = 'type',
    )
)
glTexSubImage3D = images.setDimensionsAsInts(
    images.setImageInput(
        simple.glTexSubImage3D,
        typeName = 'type',
    )
)
glColorTable = images.setDimensionsAsInts(
    images.setImageInput(
        simple.glColorTable,
        pixelName = 'table',
        typeName = 'type',
    )
)
glColorSubTable = images.setDimensionsAsInts(
    images.setImageInput(
        simple.glColorSubTable,
        pixelName = 'data',
    )
)
glSeparableFilter2D = images.setDimensionsAsInts(
    images.setImageInput(
        images.setImageInput(
            simple.glSeparableFilter2D,
            pixelName = 'row',
            typeName = 'type',
        ),
        pixelName = 'column',
        typeName = 'type',
    )
)
glConvolutionFilter1D = images.setDimensionsAsInts(
    images.setImageInput(
        simple.glConvolutionFilter1D,
        pixelName = 'image',
        typeName = 'type',
    )
)
glConvolutionFilter2D = images.setDimensionsAsInts(
    images.setImageInput(
        simple.glConvolutionFilter2D,
        pixelName = 'image',
        typeName = 'type',
    )
)
@lazy( simple.glGetConvolutionFilter )
def glGetConvolutionFilter( baseFunction, target, format, type ):
    """Retrieve 1 or 2D convolution parameter "kernels" as pixel data"""
    dims = ( 
        glGetConvolutionParameteriv( target, imaging.GL_CONVOLUTION_WIDTH )[0], 
    )
    if target != imaging.GL_CONVOLUTION_1D:
        dims += ( 
            glGetConvolutionParameteriv( target, imaging.GL_CONVOLUTION_HEIGHT )[0], 
        )
    # is it always 4?  Seems to be, but the spec/man-page isn't really clear about it...
    dims += (4,)
    array = images.images.SetupPixelRead( format, dims, type )
    arrayType = arrays.GL_CONSTANT_TO_ARRAY_TYPE[ 
        images.images.TYPE_TO_ARRAYTYPE.get(type,type) 
    ]
    baseFunction( 
        target, format, type,
        ctypes.c_void_p( arrayType.dataPointer(array))
    )
    return array
@lazy( simple.glGetSeparableFilter )
def glGetSeparableFilter( baseFunction, target, format, type ):
    """Retrieve 2 1D convolution parameter "kernels" as pixel data"""
    rowDims = ( 
        glGetConvolutionParameteriv( imaging.GL_CONVOLUTION_WIDTH )[0], 
        4,
    )
    columnDims = ( 
        glGetConvolutionParameteriv( imaging.GL_CONVOLUTION_HEIGHT )[0], 
        4,
    )
    arrayType = arrays.GL_CONSTANT_TO_ARRAY_TYPE[ 
        images.images.TYPE_TO_ARRAYTYPE.get(type,type) 
    ]
    row = images.images.SetupPixelRead( format, rowDims, type )
    column = images.images.SetupPixelRead( format, columnDims, type )
    baseFunction( 
        target, format, type, 
        ctypes.c_void_p( arrayType.dataPointer(row)),
        ctypes.c_void_p( arrayType.dataPointer(column)),
        None # span
    )
    return row, column
@lazy( simple.glGetColorTable )
def glGetColorTable( baseFunction, target, format, type ):
    """Retrieve the current 1D color table as a bitmap"""
    dims = ( 
        glGetColorTableParameteriv(target, imaging.GL_COLOR_TABLE_WIDTH),
        4, # Grr, spec *seems* to say that it's different sizes, but it doesn't really say...
    )
    array = images.images.SetupPixelRead( format, dims, type )
    arrayType = arrays.GL_CONSTANT_TO_ARRAY_TYPE[ 
        images.images.TYPE_TO_ARRAYTYPE.get(type,type) 
    ]
    baseFunction( 
        target, format, type,
        ctypes.c_void_p( arrayType.dataPointer(array))
    )
    return array
@lazy( simple.glGetHistogram )
def glGetHistogram( baseFunction, target, reset, format, type, values=None):
    """Retrieve current 1D histogram as a 1D bitmap"""
    if values is None:
        width = glGetHistogramParameteriv(
            target,
            imaging.GL_HISTOGRAM_WIDTH,
        )
        values = images.images.SetupPixelRead( format, (width,4), type )
    arrayType = arrays.GL_CONSTANT_TO_ARRAY_TYPE[ 
        images.images.TYPE_TO_ARRAYTYPE.get(type,type) 
    ]
    baseFunction( 
        target, reset, format, type,
        ctypes.c_void_p( arrayType.dataPointer(values))
    )
    return values

@lazy( simple.glGetMinmax )
def glGetMinmax( baseFunction, target, reset, format, type, values=None):
    """Retrieve minimum and maximum values as a 2-element image"""
    if values is None:
        width = 2
        values = images.images.SetupPixelRead( format, (width,4), type )
    arrayType = arrays.GL_CONSTANT_TO_ARRAY_TYPE[ 
        images.images.TYPE_TO_ARRAYTYPE.get(type,type) 
    ]
    baseFunction( 
        target, reset, format, type,
        ctypes.c_void_p( arrayType.dataPointer(values))
    )
    return values

# 4-items, specified in spec...
glColorTableParameterfv = arrays.setInputArraySizeType(
    simple.glColorTableParameterfv,
    4,
    arrays.GLfloatArray,
    'params',
)
GL_GET_CTP_SIZES = {
    imaging.GL_COLOR_TABLE_FORMAT :1,
    imaging.GL_COLOR_TABLE_WIDTH  :1,
    imaging.GL_COLOR_TABLE_RED_SIZE :1,
    imaging.GL_COLOR_TABLE_GREEN_SIZE :1,
    imaging.GL_COLOR_TABLE_BLUE_SIZE :1,
    imaging.GL_COLOR_TABLE_ALPHA_SIZE :1,
    imaging.GL_COLOR_TABLE_LUMINANCE_SIZE :1,
    imaging.GL_COLOR_TABLE_INTENSITY_SIZE :1,
}
glGetColorTableParameterfv = wrapper.wrapper(simple.glGetColorTableParameterfv).setOutput(
    "params",GL_GET_CTP_SIZES, "pname", 
)
glGetColorTableParameteriv = wrapper.wrapper(simple.glGetColorTableParameteriv).setOutput(
    "params",GL_GET_CTP_SIZES, "pname", 
)
GL_GET_CP_SIZES = {
    imaging.GL_CONVOLUTION_BORDER_MODE: 1,
    imaging.GL_CONVOLUTION_BORDER_COLOR: 4,
    imaging.GL_CONVOLUTION_FILTER_SCALE: 4,
    imaging.GL_CONVOLUTION_FILTER_BIAS: 4,
    imaging.GL_CONVOLUTION_FORMAT: 1,
    imaging.GL_CONVOLUTION_WIDTH: 1,
    imaging.GL_CONVOLUTION_HEIGHT: 1,
    imaging.GL_MAX_CONVOLUTION_WIDTH: 1,
    imaging.GL_MAX_CONVOLUTION_HEIGHT: 1,
}
glGetConvolutionParameteriv = wrapper.wrapper(simple.glGetConvolutionParameteriv).setOutput(
    "params",GL_GET_CP_SIZES, "pname", 
)
glGetConvolutionParameterfv = wrapper.wrapper(simple.glGetConvolutionParameterfv).setOutput(
    "params",GL_GET_CP_SIZES, "pname", 
)